@@ -49,15 +49,39 @@ try {
     $msgIdHeader = 'Message-ID: <'.uniqid('',true).'@'.php_uname('n').'>';
 
     $send_to = escapeshellarg($mailTo);
-    $sendmail = "$sendmail_cmd -i -r $mail_from $send_to 2>&1";
-    $ph = popen($sendmail,'w');
-    if (!$ph) { throw new Exception("Cannot exec command \"$sendmail\""); }
-    $ret = fwrite($ph,$msgIdHeader."\r\n".$rawMail);
-    if (!$ret) {
-        fclose($ph);
-        throw new Exception("Cannot write mail to \"$sendmail\"");
+    $sendmail = "$sendmail_cmd -i -f $mail_from $send_to 2>&1";
+
+    $fd = array(
+        0 => array('pipe', 'r'),
+        1 => array('pipe', 'w'),
+        2 => array('pipe', 'w')
+    );
+    $process = proc_open($sendmail, $fd, $pipes);
+    if (is_resource($process)) {
+        // write "<username>$auth_sep<password>"
+        fwrite($pipes[0],$msgIdHeader."\r\n".$rawMail);
+        fclose($pipes[0]);
+    
+        // read stdout from script
+        $outstring = stream_get_contents($pipes[1]);
+        fclose($pipes[1]);
+    
+        $errstring = stream_get_contents($pipes[2]);
+        fclose($pipes[2]);
+        $closevalue = proc_close($process);
+        if ($errstring) {
+            throw new Exception("Error send mail: $\"$errorvalue\" ($closevalue)");
+        }
+        if ($App->getConfig('MAIL_LOG') == 'true') {
+            if ($outstring == '') {
+                $outstring = "Sent to $mailTo";
+            }
+            error_log("SENDMAIL: $outstring");
+        }
+    }
+    else {
+        throw new Exception("Cannot exec command \"$sendmail\"");
     }
-    fclose($ph);
 
     $bennoId = QueryResult::getBennoId($sessionMailId);
     $Audit->log("MAIL $archive:".$bennoId.' >> '.$mailTo);
