@@ -52,8 +52,8 @@ class Benno
      */
     function __construct()
     {
-        $this->infoText = 'Benno MailArchiv Version 2.8.8'; 
-        $this->buildInfo= '201026172716/03e8212';
+        $this->infoText = 'Benno MailArchiv Version 2.8.9-2'; 
+        $this->buildInfo= '201210160616/333f5bd';
         $this->buildYear= '2020';
     }
 
